@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
 
 #import logging
-from Acquisition import aq_inner
+#from Acquisition import aq_inner
 from zope.i18nmessageid import MessageFactory
 from Products.Five import BrowserView
+from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 
 from plone import api
 from medialog.mobilethemeTwo.interfaces import IMobilethemeTwoSettings
 
+import requests
 import lxml.html
 import urllib 
 from lxml.cssselect import CSSSelector
 from lxml.html.clean import Cleaner
 
-import requests
-
 class Scrape(BrowserView):
     """   A View that uses lxml to embed external content    """
     
@@ -83,7 +83,7 @@ class Scrape(BrowserView):
         root_url = api.portal.get().absolute_url()
         
         #dont modyfy image links
-        if link.endswith('.jpg') or link.endswith('.png') or link.endswith('.gif') or link.endswith('.js') or link.endswith('.jpeg') or link.endswith('.pdf'):
+        if '/image' in link  or link.endswith('.jpg') or link.endswith('.png') or link.endswith('.gif') or link.endswith('.js') or link.endswith('.jpeg') or link.endswith('.pdf'):
             return link
         
         #point pages for sites enabled in  control panel to embedded view
@@ -99,12 +99,27 @@ class Scrape(BrowserView):
 class ScrapeView(BrowserView):
     """   A Dexterity Content View that redirects to the scrape view """
     
+    index = ViewPageTemplateFile("scrape_view.pt")
+
+    def render(self):
+        return self.index()
+    
+    def __init__(self, context, request):
+          self.context = context
+          self.request = request
+    
     def __call__(self):
+        context = self.context
+        if not api.user.is_anonymous():
+            if 'Modify portal content' in api.user.get_permissions(): 
+                return self.render()
+            
         root_url = api.portal.get().absolute_url()
-        selector  = self.context.scrape_selector
-        url = self.context.scrape_url
+        selector  = context.scrape_selector
+        url = context.scrape_url
     
         selector = urllib.quote(selector).decode('utf8') 
         url =      urllib.quote(url).decode('utf8')
      
         self.request.response.redirect(root_url + "/scrape?selector=" + selector + "&url=" + url )
+        
